##  AI-Generated Context
AI-generated context provides additional information and insights by analyzing existing data and context, helping users better understand tasks or requests and make informed decisions. Also, AI-generated context provides suggestions for configuration parameters in integrations, helping you streamline the configuration process.
For example, currently, the AI-generated context provides additional details and explanations for the to-dos to help you understand the task better and complete it more efficiently. It recognizes the underlying request of the to-do and considers the to-do’s description and other details in the fact sheet to generate context and help users in their tasks.
To use the AI-generated context feature in to-dos, click on the AI Help icon in the task. You can regenerate the response if needed and delete the context when no longer required.
![AI-generated Context in To-Dos](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio27530ef97a4410149a66837b39e31553_LowRes.png)
AI-Generated Context in To-Dos
As an admin user, you can use AI capabilities to generate field mapping suggestions when configuring the integration with ServiceNow. This enables you to streamline the configuration process and save time on manual mapping between SAP LeanIX and ServiceNow. For more information, see [AI-Generated Field Mapping Suggestions](https://help.sap.com/docs/leanix/ea/fact-sheet-mapping-between-servicenow-and-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD#loio275ca5f57a4410149871ec89426715ea__ai-generated_field_mapping_suggestions).
